#### MDMA004 Code - Alpha and Beta Diversity ####

#Load all necessary packages

library(phyloseq)
library(vegan)
library(ggplot2)
library(dplyr)
library(tidyr)
library(ggpubr)
library(microbiome)
library(ape)
library(tidyverse)
library(indicspecies)
library(ggVennDiagram)

#Converted our .qza files to appropriate formats and exported to local computer using the QIIME2 codes 

# Create 4 subsets of metadata
#Filter to smoker, non-smoker, healthy, abnormal

metafp <- "colombia_metadata.txt"
meta_data <- read_delim(metafp, delim="\t")

otufp <- "noMC-feature-table.txt"
otu_table <- read_delim(file = otufp, delim="\t", skip=1)

taxfp <- "taxonomy.tsv"
taxonomy <- read_delim(taxfp, delim="\t")

phylotreefp <- "tree.nwk"
phylotree <- read.tree(phylotreefp)

#Format OTU table
otu_mat <- as.matrix(otu_table[,-1])
rownames(otu_mat) <- otu_table$`#OTU ID`
OTU <- otu_table(otu_mat, taxa_are_rows = TRUE) 

#Format metadata
samp_df <- as.data.frame(meta_data[,-1])
rownames(samp_df)<- meta_data$`#SampleID`
SAMP <- sample_data(samp_df)

#Format taxonomy
tax_mat <- taxonomy %>% select(-Confidence)%>%
  separate(col=Taxon, sep="; "
           , into = c("Domain","Phylum","Class","Order","Family","Genus","Species")) %>%
  as.matrix()

tax_mat <- tax_mat[,-1]
rownames(tax_mat) <- taxonomy$`Feature ID`
TAX <- tax_table(tax_mat)

#Merge all
colombia <- phyloseq(OTU, SAMP, TAX, phylotree)
otu_table(colombia)
sample_data(colombia)
tax_table(colombia)
phy_tree(colombia)

#alpha rarefaction depth determined using QIIME2 view 
colombia_rare <- rarefy_even_depth(colombia, rngseed = 1, sample.size = 20291)

#Filter phyloseq based on metadata
#1) smoker only
colombia_smoker <- subset_samples(colombia_rare, smoker == "Yes")

#2) non-smoker only
colombia_non_smoker <- subset_samples(colombia_rare, smoker == "No")

#3) healthy only
colombia_healthy <- subset_samples(colombia_rare, Cardiometabolic_status == "Healthy")

#4) abnormal only
colombia_abnormal <- subset_samples(colombia_rare, Cardiometabolic_status == "Abnormal")

#### Alpha diversity ####

# Healthy Cardiometabolic Status Samples Only: 

CH_smoker_richness <- plot_richness(colombia_healthy, x="smoker", measures = c("Shannon","Chao1", "observed")) +
  xlab("Smoker")+geom_boxplot(aes(fill=smoker))+theme(legend.position="none")+geom_signif(comparisons = list(c("Yes", "No")),
                                                                                          map_signif_level = TRUE)

# Statistical Testing: 

CH_smoker_alpha_div <- estimate_richness(colombia_healthy)
CH_smoker_samp_dat <- sample_data(colombia_healthy)
CH_smoker_samp_dat_wdiv <- data.frame(CH_smoker_samp_dat, CH_smoker_alpha_div)

kruskal.test(Shannon ~ smoker, data = CH_smoker_samp_dat_wdiv)
# p value of 0.2432
kruskal.test(Chao1 ~ smoker, data = CH_smoker_samp_dat_wdiv)
# p value of 0.8948
kruskal.test(Observed ~ smoker, data = CH_smoker_samp_dat_wdiv)
# p value of 0.97

# Making the final version of the figures 

plot_richness(colombia_healthy, x="smoker", measures = c("Shannon","Chao1", "observed")) +
  xlab("Smoker")+ geom_boxplot(aes(fill = smoker)) +
  scale_fill_manual(values = c("blue", "red")) + 
  theme(legend.position="none") + 
  geom_signif(comparisons = list(c("Yes", "No")), map_signif_level = TRUE)


CH_Shannon_Pres <- plot_richness(colombia_healthy, x="smoker", measures = c("Shannon")) +
  xlab("Smoker") + 
  ylab(NULL) +
  geom_boxplot(aes(fill = smoker)) +
  scale_fill_manual(values = c("blue", "red")) +
  theme(legend.position="none") + 
  geom_signif(comparisons = list(c("Yes", "No")), map_signif_level = TRUE) + 
  scale_y_continuous(limits=c(0, 5))

ggsave(filename = "CH_Shannon_Pres.png"
       , CH_Shannon_Pres
       , height=4, width=1.5)


CH_Chao1_Pres <- plot_richness(colombia_healthy, x="smoker", measures = c("Chao1")) +
  xlab("Smoker") + 
  ylab(NULL) +
  geom_boxplot(aes(fill = smoker)) +
  scale_fill_manual(values = c("blue", "red")) +
  theme(legend.position="none") + 
  geom_signif(comparisons = list(c("Yes", "No")), map_signif_level = TRUE) + 
  scale_y_continuous(limits=c(50, 430))

ggsave(filename = "CH_Chao1_Pres.png"
       , CH_Chao1_Pres
       , height=4, width=1.5)

CH_Observed_Pres <- plot_richness(colombia_healthy, x="smoker", measures = c("Observed")) +
  xlab("Smoker") + 
  ylab(NULL) +
  geom_boxplot(aes(fill = smoker)) +
  scale_fill_manual(values = c("blue", "red")) +
  theme(legend.position="none") + 
  geom_signif(comparisons = list(c("Yes", "No")), map_signif_level = TRUE) + 
  scale_y_continuous(limits=c(50, 430))

ggsave(filename = "CH_observed_Pres.png"
       , CH_Observed_Pres
       , height=4, width=1.5)

# Abnormal Cardiometabolic Status Samples Only


CA_smoker_richness <- plot_richness(colombia_abnormal, x="smoker", measures = c("Shannon","Chao1", "observed")) +
  xlab("Smoker")+ geom_boxplot(aes(fill = smoker)) +
  scale_fill_manual(values = c("blue", "red")) +
  theme(legend.position="none") + 
  geom_signif(comparisons = list(c("Yes", "No")), map_signif_level = TRUE)



ggsave(filename = "CA_Smoker_Richness.png"
       , CA_smoker_richness
       , height=4, width=6)

# Statistical Testing: 

CA_smoker_alpha_div <- estimate_richness(colombia_abnormal)
CA_smoker_samp_dat <- sample_data(colombia_abnormal)
CA_smoker_samp_dat_wdiv <- data.frame(CA_smoker_samp_dat, CA_smoker_alpha_div)

kruskal.test(Shannon ~ smoker, data = CA_smoker_samp_dat_wdiv)
# p value of 0.09462
kruskal.test(Chao1 ~ smoker, data = CA_smoker_samp_dat_wdiv)
# p-value of 0.03088 for chao1
kruskal.test(Observed ~ smoker, data = CA_smoker_samp_dat_wdiv)
# p value of 0.02765 for Observed 

# Making the final version for figures:

CA_Shannon_Pres <- plot_richness(colombia_abnormal, x="smoker", measures = c("Shannon")) +
  xlab("Smoker") + 
  ylab(NULL) +
  geom_boxplot(aes(fill = smoker)) +
  scale_fill_manual(values = c("blue", "red")) +
  theme(legend.position="none") + 
  geom_signif(comparisons = list(c("Yes", "No")), map_signif_level = TRUE) + 
  scale_y_continuous(limits=c(0, 5))

ggsave(filename = "CA_Shannon_Pres.png"
       , CA_Shannon_Pres
       , height=4, width=1.5)


CA_Chao1_Pres <- plot_richness(colombia_abnormal, x="smoker", measures = c("Chao1")) +
  xlab("Smoker") + 
  ylab(NULL) +
  geom_boxplot(aes(fill = smoker)) +
  scale_fill_manual(values = c("blue", "red")) +
  theme(legend.position="none") + 
  geom_signif(comparisons = list(c("Yes", "No")), map_signif_level = TRUE) + 
  scale_y_continuous(limits=c(50, 430))

ggsave(filename = "CA_Chao1_Pres.png"
       , CA_Chao1_Pres
       , height=4, width=1.5)

CA_Observed_Pres <- plot_richness(colombia_abnormal, x="smoker", measures = c("Observed")) +
  xlab("Smoker") + 
  ylab(NULL) +
  geom_boxplot(aes(fill = smoker)) +
  scale_fill_manual(values = c("blue", "red")) +
  theme(legend.position="none") + 
  geom_signif(comparisons = list(c("Yes", "No")), map_signif_level = TRUE) + 
  scale_y_continuous(limits=c(50, 430))

ggsave(filename = "CA_observed_Pres.png"
       , CA_Observed_Pres
       , height=4, width=1.5)


# Non-smoking Samples Only 

NS_CMS_richness <- plot_richness(colombia_non_smoker, x="Cardiometabolic_status") +
  xlab("Cardiometabolic Status")+geom_boxplot()

ggsave(filename = "NS_CMS_Richness.png"
       , NS_CMS_richness
       , height=4, width=6)

# Statistical Testing 

NS_CMS_alpha_div <- estimate_richness(colombia_non_smoker)
NS_CMS_samp_dat <- sample_data(colombia_non_smoker)
NS_CMS_samp_dat_wdiv <- data.frame(NS_CMS_samp_dat, NS_CMS_alpha_div)

kruskal.test(Shannon ~ Cardiometabolic_status, data = NS_CMS_samp_dat_wdiv)
# p value of 0.4111
kruskal.test(Chao1 ~ Cardiometabolic_status, data = NS_CMS_samp_dat_wdiv)
# p value of 0.3969

# Smoking Samples Only 

S_CMS_richness <- plot_richness(colombia_smoker, x="Cardiometabolic_status") +
  xlab("Cardiometabolic Status")+geom_boxplot()

ggsave(filename = "S_CMS_Richness.png"
       , S_CMS_richness
       , height=4, width=6)

# Statistical Testing 

S_CMS_alpha_div <- estimate_richness(colombia_smoker)
S_CMS_samp_dat <- sample_data(colombia_smoker)
S_CMS_samp_dat_wdiv <- data.frame(S_CMS_samp_dat, S_CMS_alpha_div)

kruskal.test(Shannon ~ Cardiometabolic_status, data = S_CMS_samp_dat_wdiv)
# p value of 0.06913
kruskal.test(Chao1 ~ Cardiometabolic_status, data = S_CMS_samp_dat_wdiv)
# p value of 0.053


#### Beta diversity ####

# Cardiometabolically Healthy Samples Only + Statistical Testing 

CH_smoker_bc_dm <- distance(colombia_healthy, method="bray")
CH_smoker_pcoa_bc <- ordinate(colombia_healthy, method="PCoA", distance=CH_smoker_bc_dm)

plot_ordination(colombia_healthy, CH_smoker_pcoa_bc, color = "smoker") +
  labs(col = "Smoker") + stat_ellipse()

datCH_smoker <- data.frame(sample_data(colombia_healthy))
adonis2(CH_smoker_bc_dm ~ smoker, data = datCH_smoker)


CH_smoker_j_dm <- distance(colombia_healthy, method="jaccard")
CH_smoker_pcoa_j <- ordinate(colombia_healthy, method="PCoA", distance=CH_smoker_j_dm)

plot_ordination(colombia_healthy, CH_smoker_pcoa_j, color = "smoker") +
  labs(col = "Smoker") + stat_ellipse()

adonis2(CH_smoker_j_dm ~ smoker, data = datCH_smoker)



CH_smoker_uni_dm <- distance(colombia_healthy, method="unifrac")
CH_smoker_pcoa_uni <- ordinate(colombia_healthy, method="PCoA", distance=CH_smoker_uni_dm)

plot_ordination(colombia_healthy, CH_smoker_pcoa_uni, color = "smoker") +
  labs(col = "Smoker") + 
  stat_ellipse() + 
  scale_color_manual(values = c("Yes" = "red", "No" = "blue")) +
  theme(legend.position="none")

adonis2(CH_smoker_uni_dm ~ smoker, data = datCH_smoker)


CH_smoker_wuni_dm <- distance(colombia_healthy, method="wunifrac")
CH_smoker_pcoa_wuni <- ordinate(colombia_healthy, method="PCoA", distance=CH_smoker_wuni_dm)

plot_ordination(colombia_healthy, CH_smoker_pcoa_wuni, color = "smoker") +
  labs(col = "Smoker") + stat_ellipse()

adonis2(CH_smoker_wuni_dm ~ smoker, data = datCH_smoker)

# Cardiometabolically Abnormal Samples Only + Statistical Testing: 

CA_smoker_bc_dm <- distance(colombia_abnormal, method="bray")
CA_smoker_pcoa_bc <- ordinate(colombia_abnormal, method="PCoA", distance=bc_dm1)

plot_ordination(colombia_abnormal, CA_smoker_pcoa_bc, color = "smoker") +
  labs(col = "Smoker") + stat_ellipse()

datCA_smoker <- data.frame(sample_data(colombia_abnormal))
adonis2(CA_smoker_bc_dm ~ smoker, data = datCA_smoker)

CA_smoker_j_dm <- distance(colombia_abnormal, method="jaccard")
CA_smoker_pcoa_j <- ordinate(colombia_abnormal, method="PCoA", distance=CA_smoker_j_dm)

plot_ordination(colombia_abnormal, CA_smoker_pcoa_j, color = "smoker") +
  labs(col = "Smoker") + stat_ellipse()

adonis2(CA_smoker_j_dm ~ smoker, data = datCA_smoker)


CA_smoker_uni_dm <- distance(colombia_abnormal, method="unifrac")
CA_smoker_pcoa_uni <- ordinate(colombia_abnormal, method="PCoA", distance=CA_smoker_uni_dm)

plot_ordination(colombia_abnormal, CA_smoker_pcoa_uni, color = "smoker") +
  labs(col = "Smoker") + 
  stat_ellipse() +
  scale_color_manual(values = c("Yes" = "red", "No" = "blue")) +
  theme(legend.position="none")

adonis2(CA_smoker_uni_dm ~ smoker, data = datCA_smoker)

CA_smoker_wuni_dm <- distance(colombia_abnormal, method="wunifrac")
CA_smoker_pcoa_wuni <- ordinate(colombia_abnormal, method="PCoA", distance=CA_smoker_wuni_dm)

plot_ordination(colombia_abnormal, CA_smoker_pcoa_wuni, color = "smoker") +
  labs(col = "Smoker") + stat_ellipse()

adonis2(CA_smoker_wuni_dm ~ smoker, data = datCA_smoker)


# Smoking Samples Only + Statistical Testing: 

S_CMS_bc_dm <- distance(colombia_smoker, method="bray")
S_CMS_pcoa_bc <- ordinate(colombia_smoker, method="PCoA", S_CMS_bc_dm)

plot_ordination(colombia_smoker, S_CMS_pcoa_bc, color = "Cardiometabolic_status") +
  labs(col = "Cardiometabolic Status") + stat_ellipse()

datS_CMS <- data.frame(sample_data(colombia_smoker))
adonis2(S_CMS_bc_dm ~ Cardiometabolic_status, data = datS_CMS)


S_CMS_j_dm <- distance(colombia_smoker, method="jaccard")
S_CMS_pcoa_j <- ordinate(colombia_smoker, method="PCoA", S_CMS_j_dm)

plot_ordination(colombia_smoker, S_CMS_pcoa_j, color = "Cardiometabolic_status") +
  labs(col = "Cardiometabolic Status") + stat_ellipse()

adonis2(S_CMS_j_dm ~ Cardiometabolic_status, data = datS_CMS)


S_CMS_uni_dm <- distance(colombia_smoker, method="unifrac")
S_CMS_pcoa_uni <- ordinate(colombia_smoker, method="PCoA", S_CMS_uni_dm)

plot_ordination(colombia_smoker, S_CMS_pcoa_uni, color = "Cardiometabolic_status") +
  labs(col = "Cardiometabolic Status") + stat_ellipse()

adonis2(S_CMS_uni_dm ~ Cardiometabolic_status, data = datS_CMS)



S_CMS_wuni_dm <- distance(colombia_smoker, method="wunifrac")
S_CMS_pcoa_wuni <- ordinate(colombia_smoker, method="PCoA", S_CMS_wuni_dm)

plot_ordination(colombia_smoker, S_CMS_pcoa_wuni, color = "Cardiometabolic_status") +
  labs(col = "Cardiometabolic Status") + stat_ellipse()

adonis2(S_CMS_wuni_dm ~ Cardiometabolic_status, data = datS_CMS)


# Nonsmoking Samples Only + Statistical Testing:

NS_CMS_bc_dm <- distance(colombia_non_smoker, method="bray")
NS_CMS_pcoa_bc <- ordinate(colombia_non_smoker, method="PCoA", distance=NS_CMS_bc_dm)

plot_ordination(colombia_non_smoker, NS_CMS_pcoa_bc, color = "Cardiometabolic_status") +
  labs(col = "Cardiometabolic Status") + stat_ellipse()

datNS_CMS <- data.frame(sample_data(colombia_non_smoker))
adonis2(NS_CMS_bc_dm ~ Cardiometabolic_status, data = datNS_CMS)


NS_CMS_j_dm <- distance(colombia_non_smoker, method="jaccard")
NS_CMS_pcoa_j <- ordinate(colombia_non_smoker, method="PCoA", distance=NS_CMS_j_dm)

plot_ordination(colombia_non_smoker, NS_CMS_pcoa_j, color = "Cardiometabolic_status") +
  labs(col = "Cardiometabolic Status") + stat_ellipse()

adonis2(NS_CMS_j_dm ~ Cardiometabolic_status, data = datNS_CMS)


NS_CMS_uni_dm <- distance(colombia_non_smoker, method="unifrac")
NS_CMS_pcoa_uni <- ordinate(colombia_non_smoker, method="PCoA", distance=NS_CMS_uni_dm)

plot_ordination(colombia_non_smoker, NS_CMS_pcoa_uni, color = "Cardiometabolic_status") +
  labs(col = "Cardiometabolic Status") + stat_ellipse()

adonis2(NS_CMS_uni_dm ~ Cardiometabolic_status, data = datNS_CMS)


NS_CMS_wuni_dm <- distance(colombia_non_smoker, method="wunifrac")
NS_CMS_pcoa_wuni <- ordinate(colombia_non_smoker, method="PCoA", distance=NS_CMS_wuni_dm)

plot_ordination(colombia_non_smoker, NS_CMS_pcoa_wuni, color = "Cardiometabolic_status") +
  labs(col = "Cardiometabolic Status") + stat_ellipse()

adonis2(NS_CMS_wuni_dm ~ Cardiometabolic_status, data = datNS_CMS)




